@@ -802,6 +802,11 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 			for (var i = 0; i < a.length; i ++) r += a[i];
 			return r / a.length
 		},
+		avgabs: function() {
+			var a = jsapi.array.flat(arguments), r = 0;
+			for (var i = 0; i < a.length; i ++) r += Math.abs(a[i]);
+			return r / a.length
+		},
 		cbrt: function(x) {
 			return x >= 0 ? Math.pow (x, 1 / 3) : -Math.pow (-x, 1 / 3)
 		},
@@ -943,13 +948,14 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 	</jsapi>
 */
 
-	jsapi.math.color.delta = function (L1, a1, b1, L2, a2, b2, method, p1, p2, p3, debug) {
+	jsapi.math.color.delta = function (L1, a1, b1, L2, a2, b2, method, p1, p2, p3, white, l1, l2, cat, debug) {
 		/*
 			CIE 1994 & CMC calculation code derived from formulas on www.brucelindbloom.com
 			CIE 1994 code uses some alterations seen on www.farbmetrik-gall.de/cielab/korrcielab/cie94.html (see notes in code below)
 			CIE 2000 calculation code derived from Excel spreadsheet available at www.ece.rochester.edu/~gsharma/ciede2000
+			Delta ICtCp based on research by Dolby
 			
-			method: either "CIE94", "CMC", "CIE2K" or "CIE76" (default if method is not set)
+			method: either "CIE94", "CMC", "CIE2K", "ICtCp" or "CIE76" (default if method is not set)
 			
 			p1, p2, p3 arguments have different meaning for each calculation method:
 			
@@ -958,6 +964,8 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 					commonly used values are CMC(1:1) for perceptability (default if p1 and p2 are not set) and CMC(2:1) for acceptability
 				CIE 2000: p1 becomes kL (lightness) weighting factor, p2 becomes kC (chroma) weighting factor and p3 becomes kH (hue) weighting factor
 					(all three default to 1 if not set)
+			
+			white (ref. white for converson from L*a*b* to XYZ) and l1/l2 (white luminance in cd/m2) are used only for delta ICtCp
 		*/
 		for (var i = 0; i < 6; i ++) if (typeof arguments[i] != "number" || isNaN(arguments[i])) return NaN;
 		if (typeof method == "string") method = method.toLowerCase();
@@ -967,10 +975,10 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 			case "cie94":
 			case "cie1994":
 				var textiles = p1,
-					dL = L1 - L2,
+					dL = L2 - L1,
 					C1 = Math.sqrt(Math.pow(a1, 2) + Math.pow(b1, 2)),
 					C2 = Math.sqrt(Math.pow(a2, 2) + Math.pow(b2, 2)),
-					dC = C1 - C2,
+					dC = C2 - C1,
 					dH2 = Math.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2) - Math.pow(dC, 2),
 					dH = dH2 > 0 ? Math.sqrt(dH2) : 0,
 					SL = 1,
@@ -982,7 +990,10 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 					KL = textiles ? 2 : 1,
 					KC = 1,
 					KH = 1,
-					dE = Math.sqrt(Math.pow(dL / (KL * SL), 2) + Math.pow(dC / (KC * SC), 2) + Math.pow(dH / (KH * SH), 2));
+					dLw = dL / (KL * SL),
+					dCw = dC / (KC * SC),
+					dHw = dH / (KH * SH),
+					dE = Math.sqrt(Math.pow(dLw, 2) + Math.pow(dCw, 2) + Math.pow(dHw, 2));
 				break;
 			case "cmc(2:1)":
 			case "cmc21":
@@ -992,10 +1003,10 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 			case "cmc":
 				var l = typeof p1 == "number" ? p1 : 1,
 					c = typeof p2 == "number" ? p2 : 1;
-					dL = L1 - L2,
+					dL = L2 - L1,
 					C1 = Math.sqrt(Math.pow(a1, 2) + Math.pow(b1, 2)),
 					C2 = Math.sqrt(Math.pow(a2, 2) + Math.pow(b2, 2)),
-					dC = C1 - C2,
+					dC = C2 - C1,
 					dH2 = Math.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2) - Math.pow(dC, 2),
 					dH = dH2 > 0 ? Math.sqrt(dH2) : 0,
 					SL = L1 < 16 ? 0.511 : (0.040975 * L1) / (1 + 0.01765 * L1),
@@ -1004,7 +1015,10 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 					H1 = jsapi.math.deg(Math.atan2(b1, a1)) + (b1 >= 0 ? 0 : 360),
 					T = 164 <= H1 && H1 <= 345 ? 0.56 + Math.abs(0.2 * Math.cos(jsapi.math.rad(H1 + 168))) : 0.36 + Math.abs(0.4 * Math.cos(jsapi.math.rad(H1 + 35))),
 					SH = SC * (F * T + 1 - F),
-					dE = Math.sqrt(Math.pow(dL / (l * SL), 2) + Math.pow(dC / (c * SC), 2) + Math.pow(dH / SH, 2));
+					dLw = dL / (l * SL),
+					dCw = dC / (c * SC),
+					dHw = dH / SH,
+					dE = Math.sqrt(Math.pow(dLw, 2) + Math.pow(dCw, 2) + Math.pow(dHw, 2));
 				break;
 			case "00":
 			case "2k":
@@ -1054,6 +1068,9 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 					AJ = dL_ / S_L / k_L,	// dL' / k_L / S_L
 					AK = dC_ / S_C / k_C,	// dC' / k_C / S_C
 					AL = dH_ / S_H / k_H,	// dH' / k_H / S_H
+					dLw = AJ,
+					dCw = AK,
+					dHw = AL,
 					dE = Math.sqrt(Math.pow(AJ, 2) + Math.pow(AK, 2) + Math.pow(AL, 2) + R_T * AK * AL);
 				
 				if (debug) {
@@ -1069,13 +1086,55 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 				};
 				
 				break;
+			case "ictcp":
+				// Incoming L*a*b* values can match these criteria:
+				// - Relative to D50 (explicit). White a* b* != 0.
+				//   No chromatic adaptation necessary, converting to XYZ yields
+				//   original illuminant relative values. 'D50' white must be given.
+				// - Relative to given whitepoint XYZ. White a* b* == 0.
+				//   Chromatic adaptation necessary.
+				// - Relative to D50 (implicit). White a* b* == 0.
+				//   Chromatic adaptation necessary, set white to 'null'.
+				var XYZ1 = jsapi.math.color.Lab2XYZ(L1, a1, b1, white),
+					XYZ2 = jsapi.math.color.Lab2XYZ(L2, a2, b2, white),
+					XYZ1a = white == 'D50' ? XYZ1 : jsapi.math.color.adapt(XYZ1[0], XYZ1[1], XYZ1[2], white, "D65", cat),
+					XYZ2a = white == 'D50' ? XYZ2 : jsapi.math.color.adapt(XYZ2[0], XYZ2[1], XYZ2[2], white, "D65", cat),
+					//XYZ1a = XYZ1,
+					//XYZ2a = XYZ2,
+					s1 = l1 / 10000,
+					s2 = l2 / 10000,
+					ICtCp1 = jsapi.math.color.XYZ2ICtCp(XYZ1a[0] * s1, XYZ1a[1] * s1, XYZ1a[2] * s1),
+					ICtCp2 = jsapi.math.color.XYZ2ICtCp(XYZ2a[0] * s2, XYZ2a[1] * s2, XYZ2a[2] * s2),
+					I1 = ICtCp1[0], Ct1 = ICtCp1[1], Cp1 = ICtCp1[2],
+					I2 = ICtCp2[0], Ct2 = ICtCp2[1], Cp2 = ICtCp2[2],
+					L1 = I1,
+					L2 = I2,
+					a1 = Math.sqrt(0.25 * Math.pow(Ct1, 2)) * 240,
+					b1 = Cp1 * 240,
+					a2 = Math.sqrt(0.25 * Math.pow(Ct2, 2)) * 240,
+					b2 = Cp2 * 240,
+					dL = (I2 - I1) * 480,
+					C1 = Math.sqrt(0.25 * Math.pow(Ct1, 2) + Math.pow(Cp1, 2)),
+					C2 = Math.sqrt(0.25 * Math.pow(Ct2, 2) + Math.pow(Cp2, 2)),
+					dC = C2 - C1,
+					dH = 0.25 * Math.pow(Ct2 - Ct1, 2) + Math.pow(Cp2 - Cp1, 2) - Math.pow(dC, 2),
+					dH = dH > 0 ? Math.sqrt(dH) * 240 : 0,
+					dC = dC * 240,
+					dLw = dL,
+					dCw = dC,
+					dHw = dH,
+					dE = Math.sqrt(4 * Math.pow(I2 - I1, 2) + 0.25 * Math.pow(Ct2 - Ct1, 2) + Math.pow(Cp2 - Cp1, 2)) * 240;  // Normalization per Pytlarz
+				break;
 			default:
-				var dL = L1 - L2,
+				var dL = L2 - L1,
 					C1 = Math.sqrt(Math.pow(a1, 2) + Math.pow(b1, 2)),
 					C2 = Math.sqrt(Math.pow(a2, 2) + Math.pow(b2, 2)),
-					dC = C1 - C2,
+					dC = C2 - C1,
 					dH2 = Math.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2) - Math.pow(dC, 2),
 					dH = dH2 > 0 ? Math.sqrt(dH2) : 0,
+					dLw = dL,
+					dCw = dC,
+					dHw = dH,
 					dE = Math.sqrt(Math.pow(dL, 2) + Math.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2));
 					if (isNaN(dH)) {
 						if (window.location.href.indexOf("?debug")>-1) alert('a1: ' + a1 + '\na2: ' + a2 + '\nMath.pow(a1 - a2, 2): ' + Math.pow(a1 - a2, 2) + '\nb1: ' + b1 + '\nb2: ' + b2 + '\nMath.pow(b1 - b2, 2): ' + Math.pow(b1 - b2, 2) + '\ndC: ' + dC + '\nMath.pow(dC, 2): ' + Math.pow(dC, 2) + '\nMath.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2) - Math.pow(dC, 2): ' + (Math.pow(a1 - a2, 2) + Math.pow(b1 - b2, 2) - Math.pow(dC, 2)));
@@ -1088,6 +1147,10 @@ props.push((/\s/.test(i) ? "'" : "") + i + (/\s/.test(i) ? "'" : "") + ":" + (ty
 			C: dC,
 			H: dH,
 			a: a1 - a2,
-			b: b1 - b2
+			b: b1 - b2,
+			// Weighted
+			Lw: dLw,
+			Cw: dCw,
+			Hw: dHw
 		};
 	};
